==> argo-cd-2.0.2.tar.gz: argo-cd-2.0.2/docs/user-guide/commands/argocd_cert_add-ssh.md <==
## argocd cert add-ssh

Add SSH known host entries for repository servers

```
argocd cert add-ssh --batch [flags]
```

### Options

```
      --batch         Perform batch processing by reading in SSH known hosts data (mandatory flag)
      --from string   Read SSH known hosts data from file (default is to read from stdin)
  -h, --help          help for add-ssh
      --upsert        Replace existing SSH server public host keys if key is different in input
```

### Options inherited from parent commands

```
      --auth-token string               Authentication token
      --client-crt string               Client certificate file
      --client-crt-key string           Client certificate key file
      --config string                   Path to Argo CD config (default "/home/user/.argocd/config")
      --grpc-web                        Enables gRPC-web protocol. Useful if Argo CD server is behind proxy which does not support HTTP2.
      --grpc-web-root-path string       Enables gRPC-web protocol. Useful if Argo CD server is behind proxy which does not support HTTP2. Set web root.
  -H, --header strings                  Sets additional header to all requests made by Argo CD CLI. (Can be repeated multiple times to add multiple headers, also supports comma separated headers)
      --insecure                        Skip server certificate and domain verification
      --logformat string                Set the logging format. One of: text|json (default "text")
      --loglevel string                 Set the logging level. One of: debug|info|warn|error (default "info")
      --plaintext                       Disable TLS
      --port-forward                    Connect to a random argocd-server port using port forwarding
      --port-forward-namespace string   Namespace name which should be used for port forwarding
      --server string                   Argo CD server address
      --server-crt string               Server certificate file
```

### SEE ALSO

* [argocd cert](argocd_cert.md)	 - Manage repository certificates and SSH known hosts entries

==> argo-cd-2.3.4.tar.gz: argo-cd-2.3.4/docs/user-guide/commands/argocd_cert_add-ssh.md <==
## argocd cert add-ssh

Add SSH known host entries for repository servers

```
argocd cert add-ssh --batch [flags]
```

### Options

```
      --batch         Perform batch processing by reading in SSH known hosts data (mandatory flag)
      --from string   Read SSH known hosts data from file (default is to read from stdin)
  -h, --help          help for add-ssh
      --upsert        Replace existing SSH server public host keys if key is different in input
```

### Options inherited from parent commands

```
      --auth-token string               Authentication token
      --client-crt string               Client certificate file
      --client-crt-key string           Client certificate key file
      --config string                   Path to Argo CD config (default "/home/user/.config/argocd/config")
      --core                            If set to true then CLI talks directly to Kubernetes instead of talking to Argo CD API server
      --grpc-web                        Enables gRPC-web protocol. Useful if Argo CD server is behind proxy which does not support HTTP2.
      --grpc-web-root-path string       Enables gRPC-web protocol. Useful if Argo CD server is behind proxy which does not support HTTP2. Set web root.
  -H, --header strings                  Sets additional header to all requests made by Argo CD CLI. (Can be repeated multiple times to add multiple headers, also supports comma separated headers)
      --http-retry-max int              Maximum number of retries to establish http connection to Argo CD server
      --insecure                        Skip server certificate and domain verification
      --logformat string                Set the logging format. One of: text|json (default "text")
      --loglevel string                 Set the logging level. One of: debug|info|warn|error (default "info")
      --plaintext                       Disable TLS
      --port-forward                    Connect to a random argocd-server port using port forwarding
      --port-forward-namespace string   Namespace name which should be used for port forwarding
      --server string                   Argo CD server address
      --server-crt string               Server certificate file
```

### SEE ALSO

* [argocd cert](argocd_cert.md)	 - Manage repository certificates and SSH known hosts entries
